==> crm-commom-1.0.4.release.jar: com/biz/crm/config/LoginInterceptor.java <==
package com.biz.crm.config;

import com.alibaba.fastjson.JSON;
import com.biz.crm.base.config.ThreadLocalUtil;
import com.biz.crm.util.*;
import com.github.pagehelper.util.StringUtil;
import lombok.extern.slf4j.Slf4j;
import org.redisson.api.RBucket;
import org.redisson.api.RMap;
import org.redisson.api.RedissonClient;
import org.redisson.client.codec.StringCodec;
import org.springframework.lang.Nullable;
import org.springframework.security.authentication.UsernamePasswordAuthenticationToken;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.security.core.context.SecurityContextImpl;
import org.springframework.web.servlet.HandlerInterceptor;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.PrintWriter;
import java.util.List;

/**
 * @author jianglong
 * @version V1.0
 * @Package com.biz.crm.config
 * @Description: TODO
 * @date 2020/8/28 下午2:23
 */
@Slf4j
public class LoginInterceptor implements HandlerInterceptor {
    @Override
    public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler) throws Exception {
        ThreadLocalUtil.clear();
//        Authentication authentication  = SecurityContextHolder.getContext().getAuthentication();
//        UserRedis userRedis = UserUtils.getUser();
//        if (userRedis == null || StringUtil.isEmpty(userRedis.getUsername())) {
//            //获取请求IP地址
//            String ip = IpUtil.getIpAddrByRequest(HttpServletRequestUtil.getRequest());
//            log.error("没有登录权限 -> [{}]", ip);
//            this.loginVaild(response);
//            return false;
//        }
        return true;
    }



//    /**
//     * 登录失效返回
//     *
//     * @param response
//     * @throws Exception
//     */
//    private void loginVaild(HttpServletResponse response) throws Exception {
//        Result result = new Result();
//        result.error401("请重新登录");
//        response.setContentType("application/json");
//        PrintWriter out = response.getWriter();
//        out.print(JSON.toJSONString(result));
//        out.flush();
//    }
    @Override
    public void afterCompletion(HttpServletRequest request, HttpServletResponse response, Object handler, @Nullable Exception ex) throws Exception {
        ThreadLocalUtil.clear();
    }
}

==> crm-commom-1.1.0.release.jar: com/biz/crm/config/LoginInterceptor.java <==
package com.biz.crm.config;

import com.biz.crm.base.config.ThreadLocalUtil;
import com.biz.crm.common.GlobalParam;
import lombok.extern.slf4j.Slf4j;
import org.springframework.lang.Nullable;
import org.springframework.stereotype.Component;
import org.springframework.web.servlet.HandlerInterceptor;
import org.springframework.web.servlet.handler.HandlerInterceptorAdapter;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.concurrent.ConcurrentHashMap;

/**
 * @author jianglong
 * @version V1.0
 * @Package com.biz.crm.config
 * @Description: TODO
 * @date 2020/8/28 下午2:23
 */
@Slf4j
public class LoginInterceptor implements HandlerInterceptor {
    @Override
    public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler) throws Exception {
        ThreadLocalUtil.clear();
        return true;
    }



//    /**
//     * 登录失效返回
//     *
//     * @param response
//     * @throws Exception
//     */
//    private void loginVaild(HttpServletResponse response) throws Exception {
//        Result result = new Result();
//        result.error401("请重新登录");
//        response.setContentType("application/json");
//        PrintWriter out = response.getWriter();
//        out.print(JSON.toJSONString(result));
//        out.flush();
//    }
    @Override
    public void afterCompletion(HttpServletRequest request, HttpServletResponse response, Object handler, @Nullable Exception ex) throws Exception {
        ThreadLocalUtil.clear();
    }
}
